@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Ben Cooksley <bcooksley@kde.org>                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "SettingsBase.h"
 #include "BaseConfig.h"
@@ -132,6 +119,11 @@ void SettingsBase::initApplication()
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("systemsettingsview/"));
 
     for (const KPluginMetaData &plugin : plugins) {
+        // Make sure we only load one plugin per type if we're installed on multiple prefixes
+        if (possibleViews.contains(plugin.pluginId())) {
+            continue;
+        }
+
         KPluginLoader loader(plugin.fileName());
         KPluginFactory *factory = loader.factory();
         if (!factory) {
@@ -219,7 +211,7 @@ void SettingsBase::initConfig()
     // Add our page
     QWidget *configPage = new QWidget(configDialog);
     configWidget.setupUi(configPage);
-    QString iconName = KAboutData::applicationData().programIconName();
+    QString iconName = QApplication::windowIcon().name();
     configDialog->addPage(configPage, i18nc("General config for System Settings", "General"), iconName);
     QVBoxLayout *configLayout = new QVBoxLayout;
     // Get the list of modules
@@ -234,6 +226,9 @@ void SettingsBase::initConfig()
     configWidget.GbViewStyle->setVisible(possibleViews.count() > 1);
     KWindowConfig::restoreWindowSize(configDialog->windowHandle(), KSharedConfig::openConfig()->group("ConfigDialog"));
     connect(configDialog, &KConfigDialog::accepted, this, &SettingsBase::configUpdated);
+    // Need to set size manually here since the .ui file doesn't produce the right
+    // autogenerated code to do it correctly
+    configDialog->resize(QSize(420, 300));
 }
 
 void SettingsBase::initMenuList(MenuItem *parent)
@@ -282,16 +277,24 @@ void SettingsBase::initMenuList(MenuItem *parent)
             ? parent->service()->property(QStringLiteral("X-KDE-System-Settings-Category-Module")).toString()
             : QString();
 
+        bool isCategoryOwner = false;
+
         if (!parentCategoryKcm.isEmpty() && parentCategoryKcm == entry->library()) {
             parent->setItem(KCModuleInfo(entry));
-            removeList.append(modules.at(i));
-        } else if (!parent->category().isEmpty() && (category == parent->category() || category2 == parent->category())) {
+            isCategoryOwner = true;
+        }
+
+        if (!parent->category().isEmpty() && (category == parent->category() || category2 == parent->category())) {
             if (!entry->noDisplay()) {
                 // Add the module info to the menu
                 MenuItem *infoItem = new MenuItem(false, parent);
                 infoItem->setService(entry);
+                infoItem->setCategoryOwner(isCategoryOwner);
+
                 if (m_mode == BaseMode::InfoCenter && entry->pluginKeyword() == QStringLiteral("kcm-about-distro")) {
                     homeModule = infoItem;
+                } else if (m_mode == BaseMode::SystemSettings && entry->pluginKeyword() == QStringLiteral("kcm_landingpage")) {
+                    homeModule = infoItem;
                 }
             }
 
