@@ -1,22 +1,9 @@
-/*****************************************************************************
- *   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                     *
- *   Copyright (C) 2009 by Mathias Soeken <msoeken@informatik.uni-bremen.de> *
- *                                                                           *
- *   This program is free software; you can redistribute it and/or modify    *
- *   it under the terms of the GNU General Public License as published by    *
- *   the Free Software Foundation; either version 2 of the License, or       *
- *   (at your option) any later version.                                     *
- *                                                                           *
- *   This program is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
- *   GNU General Public License for more details.                            *
- *                                                                           *
- *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, write to the                           *
- *   Free Software Foundation, Inc.,                                         *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA            *
- *****************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *   SPDX-FileCopyrightText: 2009 Mathias Soeken <msoeken@informatik.uni-bremen.de>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "ModuleView.h"
 #include "ExternalAppModule.h"
@@ -314,7 +301,8 @@ void ModuleView::updatePageIconHeader(KPageWidgetItem *page, bool light)
     page->setHeader(moduleInfo->moduleName());
     page->setIcon(QIcon::fromTheme(moduleInfo->icon()));
 
-    d->mCustomHeader->setVisible(false);
+    const bool isQml = (moduleProxy && moduleProxy->realModule() && moduleProxy->realModule()->inherits("KCModuleQml"));
+    d->mCustomHeader->setVisible(!isQml);
     page->setHeaderVisible(false);
 
     if (light) {
@@ -391,7 +379,7 @@ bool ModuleView::moduleSave(KCModuleProxy *module)
     }
 
     module->save();
-    emit moduleSaved();
+    Q_EMIT moduleSaved();
     return true;
 }
 
@@ -447,13 +435,21 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
     KCModuleProxy *activeModule = d->mPages.value(d->mPageWidget->currentPage());
     if (activeModule || activeModuleInfo) {
         // TODO: if we'll ever need statistics for kinfocenter modules, save them with an URL like "kinfo:"
-        if (activeModule && d->mSaveStatistics) {
+
+        if (activeModule && d->mSaveStatistics && activeModule->moduleInfo().service()->desktopEntryName() != QStringLiteral("kcm_landingpage")) {
             KActivities::ResourceInstance::notifyAccessed(QUrl(QStringLiteral("kcm:") + activeModule->moduleInfo().service()->storageId()),
                                                           QStringLiteral("org.kde.systemsettings"));
         }
 
         d->mCustomHeader->setText(activeModuleInfo->moduleName());
 
+        d->mLayout->setContentsMargins(0, 0, 0, 0);
+        d->mLayout->setSpacing(0);
+        d->mButtons->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                                        0, // Remove extra space between KCM content and bottom buttons
+                                        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+
         const bool isQml = (activeModule && activeModule->realModule() && activeModule->realModule()->inherits("KCModuleQml"));
         d->mCustomHeader->setVisible(!isQml);
         current->setHeaderVisible(!isQml);
@@ -466,13 +462,6 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
             d->mCustomHeader->setVisible(false);
             current->setHeaderVisible(false);
 
-            d->mButtons->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-                                            0, // Remove extra space between KCM content and bottom buttons
-                                            style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-                                            style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
-            d->mLayout->setContentsMargins(0, 0, 0, 0);
-            d->mLayout->setSpacing(0);
-
             // QWidget KCM
         } else {
             // Sidebar mode
@@ -481,22 +470,14 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
                 current->setHeaderVisible(false);
                 gridLayout->setHorizontalSpacing(0);
 
-                d->mLayout->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-                                               style()->pixelMetric(QStyle::PM_LayoutTopMargin),
-                                               style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-                                               style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
-
                 // Icons mode
             } else {
                 d->mCustomHeader->setVisible(false);
                 current->setHeaderVisible(true);
                 gridLayout->setHorizontalSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
-                d->mLayout->setContentsMargins(0, 0, 0, 0);
             }
-
-            d->mButtons->setContentsMargins(0, 0, 0, 0);
-            d->mLayout->setSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
         }
+
         moduleShowDefaultsIndicators(d->mDefaultsIndicatorsVisible);
     }
 }
@@ -537,7 +518,7 @@ void ModuleView::stateChanged()
     d->mReset->setVisible(buttons & KCModule::Apply);
     d->mHelp->setEnabled(buttons & KCModule::Help);
     d->mHelp->setVisible(buttons & KCModule::Help);
-    emit moduleChanged(change);
+    Q_EMIT moduleChanged(change);
 }
 
 void ModuleView::keyPressEvent(QKeyEvent *event)
@@ -548,7 +529,7 @@ void ModuleView::keyPressEvent(QKeyEvent *event)
         return;
     } else if (event->key() == Qt::Key_Escape) {
         event->accept();
-        emit closeRequest();
+        Q_EMIT closeRequest();
         return;
     } else if (event->key() == Qt::Key_F1 && event->modifiers() == Qt::ShiftModifier) {
         QWhatsThis::enterWhatsThisMode();
